operations

package
v0.0.0-...-c66050e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2020 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CheckAllPodsOK

type CheckAllPodsOK struct {
	Payload *models.CheckAllResults
}

CheckAllPodsOK handles this case with default header values.

Success, return response

func NewCheckAllPodsOK

func NewCheckAllPodsOK() *CheckAllPodsOK

NewCheckAllPodsOK creates a CheckAllPodsOK with default headers values

func (*CheckAllPodsOK) Error

func (o *CheckAllPodsOK) Error() string

type CheckAllPodsParams

type CheckAllPodsParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CheckAllPodsParams contains all the parameters to send to the API endpoint for the check all pods operation typically these are written to a http.Request

func NewCheckAllPodsParams

func NewCheckAllPodsParams() *CheckAllPodsParams

NewCheckAllPodsParams creates a new CheckAllPodsParams object with the default values initialized.

func NewCheckAllPodsParamsWithContext

func NewCheckAllPodsParamsWithContext(ctx context.Context) *CheckAllPodsParams

NewCheckAllPodsParamsWithContext creates a new CheckAllPodsParams object with the default values initialized, and the ability to set a context for a request

func NewCheckAllPodsParamsWithHTTPClient

func NewCheckAllPodsParamsWithHTTPClient(client *http.Client) *CheckAllPodsParams

NewCheckAllPodsParamsWithHTTPClient creates a new CheckAllPodsParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewCheckAllPodsParamsWithTimeout

func NewCheckAllPodsParamsWithTimeout(timeout time.Duration) *CheckAllPodsParams

NewCheckAllPodsParamsWithTimeout creates a new CheckAllPodsParams object with the default values initialized, and the ability to set a timeout on a request

func (*CheckAllPodsParams) SetContext

func (o *CheckAllPodsParams) SetContext(ctx context.Context)

SetContext adds the context to the check all pods params

func (*CheckAllPodsParams) SetHTTPClient

func (o *CheckAllPodsParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the check all pods params

func (*CheckAllPodsParams) SetTimeout

func (o *CheckAllPodsParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the check all pods params

func (*CheckAllPodsParams) WithContext

WithContext adds the context to the check all pods params

func (*CheckAllPodsParams) WithHTTPClient

func (o *CheckAllPodsParams) WithHTTPClient(client *http.Client) *CheckAllPodsParams

WithHTTPClient adds the HTTPClient to the check all pods params

func (*CheckAllPodsParams) WithTimeout

func (o *CheckAllPodsParams) WithTimeout(timeout time.Duration) *CheckAllPodsParams

WithTimeout adds the timeout to the check all pods params

func (*CheckAllPodsParams) WriteToRequest

func (o *CheckAllPodsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a swagger request

type CheckAllPodsReader

type CheckAllPodsReader struct {
	// contains filtered or unexported fields
}

CheckAllPodsReader is a Reader for the CheckAllPods structure.

func (*CheckAllPodsReader) ReadResponse

func (o *CheckAllPodsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CheckServicePodsOK

type CheckServicePodsOK struct {
	Payload *models.CheckResults
}

CheckServicePodsOK handles this case with default header values.

Success, return response

func NewCheckServicePodsOK

func NewCheckServicePodsOK() *CheckServicePodsOK

NewCheckServicePodsOK creates a CheckServicePodsOK with default headers values

func (*CheckServicePodsOK) Error

func (o *CheckServicePodsOK) Error() string

type CheckServicePodsParams

type CheckServicePodsParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CheckServicePodsParams contains all the parameters to send to the API endpoint for the check service pods operation typically these are written to a http.Request

func NewCheckServicePodsParams

func NewCheckServicePodsParams() *CheckServicePodsParams

NewCheckServicePodsParams creates a new CheckServicePodsParams object with the default values initialized.

func NewCheckServicePodsParamsWithContext

func NewCheckServicePodsParamsWithContext(ctx context.Context) *CheckServicePodsParams

NewCheckServicePodsParamsWithContext creates a new CheckServicePodsParams object with the default values initialized, and the ability to set a context for a request

func NewCheckServicePodsParamsWithHTTPClient

func NewCheckServicePodsParamsWithHTTPClient(client *http.Client) *CheckServicePodsParams

NewCheckServicePodsParamsWithHTTPClient creates a new CheckServicePodsParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewCheckServicePodsParamsWithTimeout

func NewCheckServicePodsParamsWithTimeout(timeout time.Duration) *CheckServicePodsParams

NewCheckServicePodsParamsWithTimeout creates a new CheckServicePodsParams object with the default values initialized, and the ability to set a timeout on a request

func (*CheckServicePodsParams) SetContext

func (o *CheckServicePodsParams) SetContext(ctx context.Context)

SetContext adds the context to the check service pods params

func (*CheckServicePodsParams) SetHTTPClient

func (o *CheckServicePodsParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the check service pods params

func (*CheckServicePodsParams) SetTimeout

func (o *CheckServicePodsParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the check service pods params

func (*CheckServicePodsParams) WithContext

WithContext adds the context to the check service pods params

func (*CheckServicePodsParams) WithHTTPClient

func (o *CheckServicePodsParams) WithHTTPClient(client *http.Client) *CheckServicePodsParams

WithHTTPClient adds the HTTPClient to the check service pods params

func (*CheckServicePodsParams) WithTimeout

WithTimeout adds the timeout to the check service pods params

func (*CheckServicePodsParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type CheckServicePodsReader

type CheckServicePodsReader struct {
	// contains filtered or unexported fields
}

CheckServicePodsReader is a Reader for the CheckServicePods structure.

func (*CheckServicePodsReader) ReadResponse

func (o *CheckServicePodsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for operations API

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) *Client

New creates a new operations API client.

func (*Client) CheckAllPods

func (a *Client) CheckAllPods(params *CheckAllPodsParams) (*CheckAllPodsOK, error)

CheckAllPods Queries the API server for all other pods in this service, and makes all of them query all of their neighbours, using their pods IPs. Calls their /check endpoint.

func (*Client) CheckServicePods

func (a *Client) CheckServicePods(params *CheckServicePodsParams) (*CheckServicePodsOK, error)

CheckServicePods Queries the API server for all other pods in this service, and pings them via their pods IPs. Calls their /ping endpoint

func (*Client) Healthz

func (a *Client) Healthz(params *HealthzParams) (*HealthzOK, error)

Healthz The healthcheck endpoint provides detailed information about the health of a web service. If each of the components required by the service are healthy, then the service is considered healthy and will return a 200 OK response. If any of the components needed by the service are unhealthy, then a 503 Service Unavailable response will be provided.

func (*Client) Ping

func (a *Client) Ping(params *PingParams) (*PingOK, error)

Ping return query stats

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type HealthzOK

type HealthzOK struct {
	Payload *models.HealthCheckResults
}

HealthzOK handles this case with default header values.

Health check report

func NewHealthzOK

func NewHealthzOK() *HealthzOK

NewHealthzOK creates a HealthzOK with default headers values

func (*HealthzOK) Error

func (o *HealthzOK) Error() string

type HealthzParams

type HealthzParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

HealthzParams contains all the parameters to send to the API endpoint for the healthz operation typically these are written to a http.Request

func NewHealthzParams

func NewHealthzParams() *HealthzParams

NewHealthzParams creates a new HealthzParams object with the default values initialized.

func NewHealthzParamsWithContext

func NewHealthzParamsWithContext(ctx context.Context) *HealthzParams

NewHealthzParamsWithContext creates a new HealthzParams object with the default values initialized, and the ability to set a context for a request

func NewHealthzParamsWithHTTPClient

func NewHealthzParamsWithHTTPClient(client *http.Client) *HealthzParams

NewHealthzParamsWithHTTPClient creates a new HealthzParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewHealthzParamsWithTimeout

func NewHealthzParamsWithTimeout(timeout time.Duration) *HealthzParams

NewHealthzParamsWithTimeout creates a new HealthzParams object with the default values initialized, and the ability to set a timeout on a request

func (*HealthzParams) SetContext

func (o *HealthzParams) SetContext(ctx context.Context)

SetContext adds the context to the healthz params

func (*HealthzParams) SetHTTPClient

func (o *HealthzParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the healthz params

func (*HealthzParams) SetTimeout

func (o *HealthzParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the healthz params

func (*HealthzParams) WithContext

func (o *HealthzParams) WithContext(ctx context.Context) *HealthzParams

WithContext adds the context to the healthz params

func (*HealthzParams) WithHTTPClient

func (o *HealthzParams) WithHTTPClient(client *http.Client) *HealthzParams

WithHTTPClient adds the HTTPClient to the healthz params

func (*HealthzParams) WithTimeout

func (o *HealthzParams) WithTimeout(timeout time.Duration) *HealthzParams

WithTimeout adds the timeout to the healthz params

func (*HealthzParams) WriteToRequest

func (o *HealthzParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a swagger request

type HealthzReader

type HealthzReader struct {
	// contains filtered or unexported fields
}

HealthzReader is a Reader for the Healthz structure.

func (*HealthzReader) ReadResponse

func (o *HealthzReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type HealthzServiceUnavailable

type HealthzServiceUnavailable struct {
	Payload *models.HealthCheckResults
}

HealthzServiceUnavailable handles this case with default header values.

Unhealthy service

func NewHealthzServiceUnavailable

func NewHealthzServiceUnavailable() *HealthzServiceUnavailable

NewHealthzServiceUnavailable creates a HealthzServiceUnavailable with default headers values

func (*HealthzServiceUnavailable) Error

func (o *HealthzServiceUnavailable) Error() string

type PingOK

type PingOK struct {
	Payload *models.PingResults
}

PingOK handles this case with default header values.

return success

func NewPingOK

func NewPingOK() *PingOK

NewPingOK creates a PingOK with default headers values

func (*PingOK) Error

func (o *PingOK) Error() string

type PingParams

type PingParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

PingParams contains all the parameters to send to the API endpoint for the ping operation typically these are written to a http.Request

func NewPingParams

func NewPingParams() *PingParams

NewPingParams creates a new PingParams object with the default values initialized.

func NewPingParamsWithContext

func NewPingParamsWithContext(ctx context.Context) *PingParams

NewPingParamsWithContext creates a new PingParams object with the default values initialized, and the ability to set a context for a request

func NewPingParamsWithHTTPClient

func NewPingParamsWithHTTPClient(client *http.Client) *PingParams

NewPingParamsWithHTTPClient creates a new PingParams object with the default values initialized, and the ability to set a custom HTTPClient for a request

func NewPingParamsWithTimeout

func NewPingParamsWithTimeout(timeout time.Duration) *PingParams

NewPingParamsWithTimeout creates a new PingParams object with the default values initialized, and the ability to set a timeout on a request

func (*PingParams) SetContext

func (o *PingParams) SetContext(ctx context.Context)

SetContext adds the context to the ping params

func (*PingParams) SetHTTPClient

func (o *PingParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the ping params

func (*PingParams) SetTimeout

func (o *PingParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the ping params

func (*PingParams) WithContext

func (o *PingParams) WithContext(ctx context.Context) *PingParams

WithContext adds the context to the ping params

func (*PingParams) WithHTTPClient

func (o *PingParams) WithHTTPClient(client *http.Client) *PingParams

WithHTTPClient adds the HTTPClient to the ping params

func (*PingParams) WithTimeout

func (o *PingParams) WithTimeout(timeout time.Duration) *PingParams

WithTimeout adds the timeout to the ping params

func (*PingParams) WriteToRequest

func (o *PingParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a swagger request

type PingReader

type PingReader struct {
	// contains filtered or unexported fields
}

PingReader is a Reader for the Ping structure.

func (*PingReader) ReadResponse

func (o *PingReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

Jump to